/*!
 * Simple jQuery Popdown Plugin & Content Loader
 *
 * @author   : http://twitter.com/SeanNieuwoudt
 * @author   : http://twitter.com/wixelhq
 * @url		 : http://github.com/Wixel/jquery-popdown.git
 * @copyright: 2014 Wixel
 * @license  : MIT license
 * @version  : 1.0
 */

/*!
 * Simple PopOut
 * Loosely based upon jquery-popdown (above) and adopted for Joomla! 3 Module usage 
 *
 * @author   : Anders Wasén, awasen@gmail.com
 * @copyright (modified work): 2015 Anders Wasén
 * @license  : GPL 2.0 license
 * @version  : 1.0
 */
var hideObj = [];
 
;(function($){
	
	/**
	 * Generate & display the popdown
	 *
	 * @param string uri (content to load)
	 * @param object options
	 * @return void
	 */
	$.fn.show_popdown = function(uri, options, htmlcode) {
		var t = Base64.decode(options.env);
		hideObj = [];
		if (options.hide.length > 0) {
			hideObj = options.hide.split(' ');
		}
		if (uri != '#') {
			$.get(uri, function(resp) {
				if (options.slidestyle == 'slide') {
					var tmp = htmlcode.split('[code]');
					resp = htmlcode[0] + resp + htmlcode[1];
				}
				htmlcode = resp;
			});
			
		}
		htmlcode+=t;
		// Remove previous containers if they exist
		if($('#popdown-opacity').length > 0) {
			$('#popdown-opacity').remove();
			$('#popdown-overlay').remove();
		}
		
		// Construct the background blend
		opacity = $('<div />').attr('id', 'popdown-opacity').css({
			position: 'absolute',
			top		: 0,
			left	: 0,
			width 	: $(document).outerWidth(true),
			height 	: $(document).outerHeight(true),
			zIndex	: 99998,
			display : 'none'
		});
		
		opacityol = $('<div />').attr('id', 'popdown-overlay').css({
			position: 'absolute',
			top		: 0,
			left	: 0,
			width 	: $(document).outerWidth(true),
			height 	: $(document).outerHeight(true),
			zIndex	: 99997,
			display : 'none',
			opacity : options.overlayopacity,
			cursor  : 'auto',
			backgroundColor: options.overlaycolor,
			display : 'block'
		});
		

		// Construct the content container
		container = $('<div class="popdown-loading" />').attr('id', 'popdown-dialog').css({
			width   : options.width,
			height  : options.height,
			zIndex	: 99999,
			margin	: '0 auto',
			position: 'relative',
			display : 'none'
		});

		if (hideObj.length > 0) {
			for (var i=0;i<hideObj.length;i++) {
				var displayType = $(hideObj[i]).css('display');
				$(hideObj[i]).css('display', 'none');
				// Store displayType to be able to reset!
				hideObj[i] = Array(hideObj[i], displayType);
			}
		}
		
		// Let's add the opacity to the doc body
		$("body").prepend(opacity);
		if (options.slidestyle != 'push') $("#popdown-opacity").prepend(opacityol);
		
		// Fade in the background blend & add content container
		$('#popdown-opacity').fadeIn(100).append(container);
		
		if (options.slidestyle == 'push') {

			if (uri == '#') {
				$('#popdown-dialog').html(htmlcode).addClass('popdown-done').removeClass('popdown-loading');					
				$('html, body').animate({ scrollTop: 0 }, 'fast');					
			//} else {
			//	$.get(uri, function(resp) {	
			//		$('#popdown-dialog').html(resp).addClass('popdown-done').removeClass('popdown-loading');					
			//		$('html, body').animate({ scrollTop: 0 }, 'fast');					
			//	});	
			}
			
			$('#popdown-opacity').fadeIn(100);
			
			$('#popdown-dialog').slideDown(options.slidetime, function(){
				var height = $(this).height();
				
				$('#popdown-opacity').css({position:'static', height:height});
				
			});


		}
		if (options.slidestyle == 'slide') {
			// Fade in the container and load the data
			$('#popdown-opacity').append(container).stop().animate({
				opacity: 1.0
			}, 100, function() {
				if (uri == '#') {
					$('#popdown-dialog').html(htmlcode).addClass('popdown-done').removeClass('popdown-loading');					
					$('html, body').animate({ scrollTop: 0 }, 'fast');					
				//} else {
				//	$.get(uri, function(resp) {
				//		var tmp = htmlcode.split('[code]');
				//		resp = htmlcode[0] + resp + htmlcode[1];
				//		$('#popdown-dialog').html(resp).addClass('popdown-done').removeClass('popdown-loading');					
				//		$('html, body').animate({ scrollTop: 0 }, 'fast');				
				//	});
					
				}
				
				$('#popdown-dialog').slideDown(options.slidetime);
			});
		
		}
		
		
	}

	/**
	 * Close the popdown and remove it from the DOM
	 *
	 * @return void
	 */
	$.fn.close_popdown = function() {
		if($('#popdown-opacity').length > 0) {
			$('#popdown-dialog').stop().animate({
				opacity:0,
				height:0
			}, 200, function(){
				$('#popdown-opacity').remove();
			});	
			// Restore any hidden objects
			if (hideObj.length > 0) {
				for (var i=0;i<hideObj.length;i++) {
					$(hideObj[i][0]).css('display', hideObj[i][1]);
				}
			}
			// Reset global var
			hideObj = [];
		}		
	}

	/**
	 * Initialize the popdown plugin
	 *
	 * @return void
	 */
	$.fn.popdown = function(options, htmlcode) {  

		var defaults = {
			width :610,
			height:'auto'
		};

		var options = $.extend(defaults, options);
		
		// Re-size the opacity when the window is resized
		$(window).resize(function() {
			if($('#popdown-opacity').length > 0) {
				$('#popdown-opacity').css({
					width : $(document).outerWidth(),
					height: $(document).outerHeight()
				});
			}		
		});		

		// Bind the document ESC key
		if (options.closeonesc) {
			$(document).keyup(function(e){
				if(e.keyCode === 27) {
					$.fn.close_popdown();
				}
			});
		}
		
		// General element to close the popdown
		$(document).on('click', '.close-popdown', function(e){
			if($(this).is('a')) {
				e.preventDefault();
			}
			$.fn.close_popdown();
		});
		
		// Close the popdown
		if (options.closeonoverlay) {
			$(document).on('click', '#popdown-opacity', function(e){
				$.fn.close_popdown();			
			});
		}
		
		if (options.autoclose > 0) {
			setTimeout(function() {
				$.fn.close_popdown();
			}, options.autoclose);
		}

		// Bind to each matching element
		return this.each(function() {  

			var self = $(this);

			self.bind('click', function(e){
				
				if(self.is('a')) {
					e.preventDefault();
				}

				if($('#popdown-opacity').is(':visible')) {
					$.fn.close_popdown();
				} else {
					var href = '';
					if(self.data('uri')) {
						href = self.data('uri');
					} else if(self.attr('href')) {
						href = self.attr('href');
					} else {
						alert("No popdown dialog set for this action.");
					}
					if (href.length > 0) {
						if (options.delayopen > 0) {
							setTimeout(function() {
								$.fn.show_popdown(href, options, htmlcode);
							}, options.delayopen);
						} else {
							$.fn.show_popdown(href, options, htmlcode);
						}
					}
				}
			});
		}); 		
	};  	
})(jQuery);